@@ -6,8 +6,8 @@ from aiofm.protocols.s3 import S3Protocol
 def main():
     protocol = S3Protocol()
 
-    for path in protocol.ls('rtu-datasets/own_transport/'):
-        if path == 'own_transport/':
+    for path in protocol.ls('/rtu-datasets/own_transport/'):
+        if str(path) == '/rtu-datasets/own_transport':
             continue
 
         print(path)
@@ -16,8 +16,8 @@ def main():
         #     for chunk in fi:
         #         fo.write(chunk)
 
-        # with protocol.open(f'rtu-datasets/{path}', 'rb') as fi, protocol.open(f'rtu-datasets/{path}.copy', 'wb') as fo:
-        #     fo.write(fi)
+        with protocol.open(path, 'rb') as fi, protocol.open(f'{path}.copy', 'wb') as fo:
+            fo.write(fi)
 
 
 if __name__ == '__main__':
